..
   Generated: Thu Mar 23 15:03:55 2017

   @author : Eric Lapouyade

=======
wrapops
=======

.. automodule:: textops.ops.wrapops
.. currentmodule:: textops

WrapOp
------
   .. autoclass:: WrapOp()

WrapOpIter
----------
   .. autoclass:: WrapOpIter()

WrapOpStr
---------
   .. autoclass:: WrapOpStr()

resub
-----
   .. autoclass:: resub(string, count=0, flags=0)
